#include "InfraredLED.h"
#include "InfraredRec.h"


//---------------------------------
// Constant

const uint8_t pinLED = 14;
const uint8_t pinSW = 0;


//---------------------------------
// Variable

InfraredRec iRec(5);  // IR receiver input pin#5
InfraredLED iLED(4);  // IR LED control pin#4


//---------------------------------
// Function

void setup() {
  Serial.begin(115200);
  delay(1);
  Serial.print("\n\n-----------------------\n");
  Serial.print("Program Start\n");
  
  pinMode(pinLED, OUTPUT);   // Green LED
  pinMode(pinSW, INPUT);     // Switch

  Serial.print("Setup finished. Waiting for IR data...\n\n");
  digitalWrite(pinLED, HIGH);  // Green LED ON
  delay(1);
}


void loop() {
  uint8_t r = iRec.readData();  // Read data from IR receiver
  
  if(r==InfraredRec::readSuccess){
    digitalWrite(pinLED, LOW);  // Green LED OFF

    // Print received data to serial
    Serial.print("Received IR Format : ");
    switch(iRec.format){
    case InfraredRec::formatAEHA:
      Serial.print("AEHA\n");
      break;
    
    case InfraredRec::formatNEC:
      Serial.print("NEC\n");
      break;
    }
    for(uint8_t i=0; i<iRec.frameCount; i++){
      Serial.print(String(" Frame")+String(i)+" : ");
      for(uint8_t j=0; j<iRec.frameSize[i]; j++){
        Serial.print(String(iRec.frameData[i][j], HEX)+"h ");
      }
      Serial.print("\n");
    }

    // Send received data after 5sec
    delay(5000);
    Serial.print("Sending data from IR LED... ");
    for(uint8_t i=0; i<iRec.frameCount; i++){
      iLED.sendFrame(iRec.format, iRec.frameData[i], iRec.frameSize[i]);
    }
    Serial.print(" Done\n\n");
    
    digitalWrite(pinLED, HIGH);  // Green LED ON
  }
}
